summaryrefslogtreecommitdiffstats
path: root/korganizer/koeditordetails.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koeditordetails.cpp')
-rw-r--r--korganizer/koeditordetails.cpp106
1 files changed, 53 insertions, 53 deletions
diff --git a/korganizer/koeditordetails.cpp b/korganizer/koeditordetails.cpp
index 2485fc96a..0b8c6159f 100644
--- a/korganizer/koeditordetails.cpp
+++ b/korganizer/koeditordetails.cpp
@@ -25,25 +25,25 @@
#include "koeditordetails.h"
-#include <qbuttongroup.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qdatetime.h>
-#include <qdragobject.h>
-#include <qfiledialog.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qregexp.h>
-#include <qtooltip.h>
-#include <qvbox.h>
-#include <qvgroupbox.h>
-#include <qwhatsthis.h>
-#include <qwidgetstack.h>
-#include <qvaluevector.h>
+#include <tqbuttongroup.h>
+#include <tqcheckbox.h>
+#include <tqcombobox.h>
+#include <tqdatetime.h>
+#include <tqdragobject.h>
+#include <tqfiledialog.h>
+#include <tqgroupbox.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
+#include <tqpushbutton.h>
+#include <tqradiobutton.h>
+#include <tqregexp.h>
+#include <tqtooltip.h>
+#include <tqvbox.h>
+#include <tqvgroupbox.h>
+#include <tqwhatsthis.h>
+#include <tqwidgetstack.h>
+#include <tqvaluevector.h>
#include <kdebug.h>
#include <klocale.h>
@@ -90,7 +90,7 @@ void CustomListViewItem<KCal::Attendee *>::updateItem()
setText(6, mData->delegator());
}
-KOAttendeeListView::KOAttendeeListView ( QWidget *parent, const char *name )
+KOAttendeeListView::KOAttendeeListView ( TQWidget *parent, const char *name )
: KListView(parent, name)
{
setAcceptDrops( true );
@@ -101,21 +101,21 @@ KOAttendeeListView::KOAttendeeListView ( QWidget *parent, const char *name )
/** KOAttendeeListView is a child class of KListView which supports
* dropping of attendees (e.g. from kaddressbook) onto it. If an attendeee
* was dropped, the signal dropped(Attendee*) is emitted. Valid drop classes
* are KVCardDrag and QTextDrag.
*/
KOAttendeeListView::~KOAttendeeListView()
{
}
-void KOAttendeeListView::contentsDragEnterEvent( QDragEnterEvent *e )
+void KOAttendeeListView::contentsDragEnterEvent( TQDragEnterEvent *e )
{
dragEnterEvent(e);
}
-void KOAttendeeListView::contentsDragMoveEvent( QDragMoveEvent *e )
+void KOAttendeeListView::contentsDragMoveEvent( TQDragMoveEvent *e )
{
#ifndef KORG_NODND
- if ( KVCardDrag::canDecode( e ) || QTextDrag::canDecode( e ) ) {
+ if ( KVCardDrag::canDecode( e ) || TQTextDrag::canDecode( e ) ) {
e->accept();
} else {
e->ignore();
@@ -123,10 +123,10 @@ void KOAttendeeListView::contentsDragMoveEvent( QDragMoveEvent *e )
#endif
}
-void KOAttendeeListView::dragEnterEvent( QDragEnterEvent *e )
+void KOAttendeeListView::dragEnterEvent( TQDragEnterEvent *e )
{
#ifndef KORG_NODND
- if ( KVCardDrag::canDecode( e ) || QTextDrag::canDecode( e ) ) {
+ if ( KVCardDrag::canDecode( e ) || TQTextDrag::canDecode( e ) ) {
e->accept();
} else {
e->ignore();
@@ -134,25 +134,25 @@ void KOAttendeeListView::dragEnterEvent( QDragEnterEvent *e )
#endif
}
-void KOAttendeeListView::addAttendee( const QString &newAttendee )
+void KOAttendeeListView::addAttendee( const TQString &newAttendee )
{
kdDebug(5850) << " Email: " << newAttendee << endl;
- QString name;
- QString email;
+ TQString name;
+ TQString email;
KPIM::getNameAndMail( newAttendee, name, email );
emit dropped( new Attendee( name, email, true ) );
}
-void KOAttendeeListView::contentsDropEvent( QDropEvent *e )
+void KOAttendeeListView::contentsDropEvent( TQDropEvent *e )
{
dropEvent(e);
}
-void KOAttendeeListView::dropEvent( QDropEvent *e )
+void KOAttendeeListView::dropEvent( TQDropEvent *e )
{
#ifndef KORG_NODND
- QString text;
- QString vcards;
+ TQString text;
+ TQString vcards;
#ifndef KORG_NOKABC
if ( KVCardDrag::decode( e, vcards ) ) {
@@ -161,7 +161,7 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
KABC::Addressee::List list = converter.parseVCards( vcards );
KABC::Addressee::List::Iterator it;
for ( it = list.begin(); it != list.end(); ++it ) {
- QString em( (*it).fullEmail() );
+ TQString em( (*it).fullEmail() );
if (em.isEmpty()) {
em=(*it).realName();
}
@@ -169,10 +169,10 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
}
} else
#endif // KORG_NOKABC
- if (QTextDrag::decode(e,text)) {
+ if (TQTextDrag::decode(e,text)) {
kdDebug(5850) << "Dropped : " << text << endl;
- QStringList emails = QStringList::split(",",text);
- for(QStringList::ConstIterator it = emails.begin();it!=emails.end();++it) {
+ TQStringList emails = TQStringList::split(",",text);
+ for(TQStringList::ConstIterator it = emails.begin();it!=emails.end();++it) {
addAttendee(*it);
}
}
@@ -180,17 +180,17 @@ void KOAttendeeListView::dropEvent( QDropEvent *e )
}
-KOEditorDetails::KOEditorDetails( int spacing, QWidget *parent,
+KOEditorDetails::KOEditorDetails( int spacing, TQWidget *parent,
const char *name )
: KOAttendeeEditor( parent, name), mDisableItemUpdate( false )
{
- QBoxLayout *topLayout = new QVBoxLayout( this );
+ TQBoxLayout *topLayout = new TQVBoxLayout( this );
topLayout->setSpacing( spacing );
initOrganizerWidgets( this, topLayout );
mListView = new KOAttendeeListView( this, "mListView" );
- QWhatsThis::add( mListView,
+ TQWhatsThis::add( mListView,
i18n("Displays information about current attendees. "
"To edit an attendee, select it in this list "
"and modify the values in the area below. "
@@ -205,22 +205,22 @@ KOEditorDetails::KOEditorDetails( int spacing, QWidget *parent,
mListView->addColumn( i18n("RSVP"), 55 );
mListView->addColumn( i18n("Delegated to"), 120 );
mListView->addColumn( i18n("Delegated from" ), 120 );
- mListView->setResizeMode( QListView::LastColumn );
+ mListView->setResizeMode( TQListView::LastColumn );
if ( KOPrefs::instance()->mCompactDialogs ) {
mListView->setFixedHeight( 78 );
}
- connect( mListView, SIGNAL( selectionChanged( QListViewItem * ) ),
- SLOT( updateAttendeeInput() ) );
+ connect( mListView, TQT_SIGNAL( selectionChanged( TQListViewItem * ) ),
+ TQT_SLOT( updateAttendeeInput() ) );
#ifndef KORG_NODND
- connect( mListView, SIGNAL( dropped( Attendee * ) ),
- SLOT( slotInsertAttendee( Attendee * ) ) );
+ connect( mListView, TQT_SIGNAL( dropped( Attendee * ) ),
+ TQT_SLOT( slotInsertAttendee( Attendee * ) ) );
#endif
topLayout->addWidget( mListView );
initEditWidgets( this, topLayout );
- connect( mRemoveButton, SIGNAL(clicked()), SLOT(removeAttendee()) );
+ connect( mRemoveButton, TQT_SIGNAL(clicked()), TQT_SLOT(removeAttendee()) );
updateAttendeeInput();
}
@@ -281,8 +281,8 @@ void KOEditorDetails::readEvent( Incidence *event )
void KOEditorDetails::writeEvent(Incidence *event)
{
event->clearAttendees();
- QValueVector<QListViewItem*> toBeDeleted;
- QListViewItem *item;
+ TQValueVector<TQListViewItem*> toBeDeleted;
+ TQListViewItem *item;
AttendeeListItem *a;
for (item = mListView->firstChild(); item;
item = item->nextSibling()) {
@@ -323,7 +323,7 @@ void KOEditorDetails::writeEvent(Incidence *event)
KOAttendeeEditor::writeEvent( event );
// cleanup
- QValueVector<QListViewItem*>::iterator it;
+ TQValueVector<TQListViewItem*>::iterator it;
for( it = toBeDeleted.begin(); it != toBeDeleted.end(); ++it ) {
delete *it;
}
@@ -336,7 +336,7 @@ bool KOEditorDetails::validateInput()
KCal::Attendee * KOEditorDetails::currentAttendee() const
{
- QListViewItem *item = mListView->selectedItem();
+ TQListViewItem *item = mListView->selectedItem();
AttendeeListItem *aItem = static_cast<AttendeeListItem *>( item );
if ( !aItem )
return 0;
@@ -357,10 +357,10 @@ void KOEditorDetails::slotInsertAttendee(Attendee * a)
void KOEditorDetails::changeStatusForMe(Attendee::PartStat status)
{
- const QStringList myEmails = KOPrefs::instance()->allEmails();
- for ( QListViewItemIterator it( mListView ); it.current(); ++it ) {
+ const TQStringList myEmails = KOPrefs::instance()->allEmails();
+ for ( TQListViewItemIterator it( mListView ); it.current(); ++it ) {
AttendeeListItem *item = static_cast<AttendeeListItem*>( it.current() );
- for ( QStringList::ConstIterator it2( myEmails.begin() ), end( myEmails.end() ); it2 != end; ++it2 ) {
+ for ( TQStringList::ConstIterator it2( myEmails.begin() ), end( myEmails.end() ); it2 != end; ++it2 ) {
if ( item->data()->email() == *it2 ) {
item->data()->setStatus( status );
item->updateItem();
@@ -101,21 +101,21 @@ KOAttendeeListView::KOAttendeeListView ( QWidget *parent, const char *name )
* dropping of attendees (e.g. from kaddressbook) onto it. If an attendeee
* was dropped, the signal dropped(Attendee*) is emitted. Valid drop classes
- * are KVCardDrag and QTextDrag.
+ * are KVCardDrag and TQTextDrag.
*/
KOAttendeeListView::~KOAttendeeListView()